#include <ansi_c.h>
#include "nidmm.h"
#include <utility.h>
#include "niswitch.h"

int main (void)
{
    ViSession instr;             /* Communication Channel */
    ViStatus status;          /* For checking errors */
    ViSession vi              = VI_NULL;
    ViInt32   function        = NIDMM_VAL_DC_VOLTS;
    ViReal64 resolution       = NIDMM_VAL_3_5_DIGITS;
    ViReal64 minFrequency     = 20.00;
    ViReal64 maxFrequency     = 25000.00;
    ViReal64  range           = 10.00;
    ViInt32   numOfMeas       = 4;
    ViReal64  measurements[4];
    ViInt32   numPointsRead, i, j;
    ViConstString channel;
   
   /* Begin by opening a communication channel to the DMM ------------------*/ 
   status = niDMM_init("DAQ::2::INSTR", VI_TRUE, VI_TRUE, &vi);
   if (status < VI_SUCCESS) {
      /* Error Initializing Interface...exiting */
      return -1;
   }
   
   /* Open a communication channel to the SCXI-1127 in slot4 ---------------*/
   status = niSwitch_init("SCXI1::4::INDEP", VI_TRUE, VI_TRUE, &instr);
   if (status < VI_SUCCESS) {
      /* Error Initializing Interface...exiting */
      return -1;
   }
   
   /*- Set Powerline frequency ---------------------------------------------*/
   status = niDMM_SetPowerlineFrequency (vi, NIDMM_VAL_60_HERTZ);
   if (status < VI_SUCCESS) {
      /* Error Configure Powerline frequency...exiting */
      return -1;
   }
   /*- Call NIDMM_Configure() to set function, range and resolution -----*/
   status = niDMM_Configure (vi, function, range, resolution, minFrequency,
                             maxFrequency); 
   if (status < VI_SUCCESS) {
      /* Error ConfigureMeasurement...exiting */
      return -1;
   }
   
   /* Close switch #ab0 */
   status = niSwitch_SingleSwitchControl(instr, "ab0", 
                                         NISWITCH_VAL_SWITCH_CLOSE );
   if (status < VI_SUCCESS) {
      /* Error Close switch #ab0...exiting */
   return -1;
   }
   
   for (i=0;i<4;i++)  {
   /*- Configure a multipoint acquisition -----------------------------------*/
   status = niDMM_ConfigureMultiPoint(vi, numOfMeas, 1, NIDMM_VAL_IMMEDIATE,
                                      0.0);
   if (status < VI_SUCCESS) {
      /* Error Configure a multipoint...exiting */
      return -1;
   }
   
   switch (i)
   {
   case 0: channel = "ch0";break;
   case 1: channel = "ch1";break;   
   case 2: channel = "ch2";break;   
   case 3: channel = "ch3";break;   
   }
   /* Close switch channel */
   status = niSwitch_SingleSwitchControl(instr, channel, 
                                         NISWITCH_VAL_SWITCH_CLOSE );
   if (status < VI_SUCCESS) {
      /* Error Close switch #0...exiting */
   return -1;
   }
   
   /*- Read measurements using NIDMM_ReadMultiPoint() -----------------------*/
   status = niDMM_ReadMultiPoint(vi, 10000, numOfMeas, measurements, 
                                 &numPointsRead);
   if (status < VI_SUCCESS) {
      /* Error Read measurements...exiting */
      return -1;
   }                              
   for (j=0;j<4;j++)
    printf("measurement[%d] = %f \n", i, measurements[i]);
   printf("\n"); 

   /* Open switch channel */
   status = niSwitch_SingleSwitchControl(instr, channel, 
                                         NISWITCH_VAL_SWITCH_OPEN );
   if (status < VI_SUCCESS) {
      /* Error Open switch #0...exiting */
   return -1;
   }
   }
      
      
   /* Close communication channel */
   status = niSwitch_close(instr);
   status = niDMM_close(vi);  
   return 0;
}
