/*****************************************************************************/
/* National Instruments Digital Multimeter                                   */
/* LabWindows/CVI 5.0 Instrument Driver Triggered Acquistion Source File     */
/*                                                                           */
/* National Instruments, Austin Texas                                        */
/* PH. (800)433-3488   Fax (512)794-5678                                     */
/* Original Release: 11-99                                                    */
/*                                                                           */
/* Modification History:                                                     */
/*     Date    Initials  Description                                         */
/*     11-99   MG        Created                                             */
/*****************************************************************************/

/*****************************************************************************\
                               Include Files
\*****************************************************************************/
#include <string.h>
#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include <userint.h>
#include <windows.h>
#include <nidmm.h>
#include <niSwitch.h> 
void _VI_FUNC messageHandler(ViStatus error);

/****************************************************************************\
  Example for calling niDMM_TriggeredAcquistion
\****************************************************************************/

void main(void)
   {
   ViStatus  error           = VI_SUCCESS;
   ViSession vi              = VI_NULL;
   ViSession instr           = VI_NULL;
   ViString  resourceName    = "DAQ::2::INSTR";
   ViString  scxichan        = "sc1!md4!ch0:2->com0;";
   ViBoolean idQuery         = VI_TRUE;
   ViBoolean reset           = VI_TRUE;
   ViReal64  powerlineFreq   = NIDMM_VAL_60_HERTZ;
   ViInt32   function        = NIDMM_VAL_DC_VOLTS;
   ViReal64  range           = 2.00;
   ViReal64  resolution      = NIDMM_VAL_3_5_DIGITS;
   ViReal64  minFrequency    = 20.00;
   ViReal64  maxFrequency    = 25000.00;
   ViInt32   startTrigSource = NIDMM_VAL_EXTERNAL;
   ViInt32   startTrigSlope  = NIDMM_VAL_POS;
   ViInt32   numOfMeas       = 30;
   ViReal64  measurements[30];
   ViInt32   timeLimit       = 30000;
   ViInt32   numPointsRead;
   ViReal64  delay           = 0.5;
   ViReal64  period;
   ViInt32   numpts,i;

   /*- NI-SWITCH configurations----------------------------------------------*/
   checkErr(niSwitch_init ("SCXI1::4::SCANNER", VI_TRUE, 
                            VI_TRUE, &instr));
   
   checkErr(niSwitch_ConfigureScanList (instr, scxichan, 
            NISWITCH_VAL_BREAK_BEFORE_MAKE));
            
   checkErr(niSwitch_ConfigureScanTrigger (instr, 0.0,
            NISWITCH_VAL_REARCONNECTOR_MODULE4,
            NISWITCH_VAL_NONE));             
            
   checkErr(niSwitch_SetContinuousScan (instr, 1));
   
   checkErr(niDMM_init(resourceName, idQuery, reset, &vi));

   /*- Call NIDMM_Configure() to set function, range and res -----*/
   checkErr(niDMM_Configure (vi, function, range, resolution, minFrequency,
                             maxFrequency));  
   
   /*- Set Powerline frequency ----------------------------------------*/
   checkErr(niDMM_SetPowerlineFrequency (vi, powerlineFreq)); 
   
   /*- Call NIDMM_Configure Trigger() to set STP delay ---------------------*/
   checkErr(niDMM_ConfigureTrigger (vi, NIDMM_VAL_IMMEDIATE, delay));

   /*- Configure a multipoint acquisition ----------------------------------*/
   checkErr(niDMM_ConfigureMultiPoint(vi, numOfMeas, 1, NIDMM_VAL_IMMEDIATE,
                                      0.05));
   /*- Get period measurement ----------------------------------------------*/
   checkErr(niDMM_GetMeasurementPeriod (vi, &period));
   
   /*- Initiate switch and DMM ---------------------------------------------*/
   checkErr(niSwitch_InitiateScan (instr));
   checkErr(niDMM_Initiate (vi));
   
   /*- Fetch 30 measurementswith DMM ---------------------------------------*/
   checkErr(niDMM_FetchMultiPoint (vi, timeLimit, 30, measurements, &numpts));
   for (i=0;i<30;i++)
    printf("measurement[%d] = %f \n", i, measurements[i]);
   printf("\n"); 
   /*- Abort and Close DMM and Switch --------------------------------------*/   
   checkErr(niDMM_Abort (vi));
   checkErr(niDMM_close (vi));
   checkErr(niSwitch_AbortScan (instr));
   checkErr(niSwitch_close (instr));


Error:
   if (vi)
      niDMM_close(vi);

   if (error < VI_SUCCESS)
      messageHandler(error);
   }



/*****************************************************************************\
  A simple error handler that calls error message, and displays the description
  in a dialog box.
\*****************************************************************************/
void _VI_FUNC messageHandler(ViStatus error)
   {
   ViChar errorMessage[256] = "";

   /*- Get the error description --------------------------------------------*/
   niDMM_error_message(VI_NULL, error, errorMessage);

   /*- Display the error message --------------------------------------------*/
   #ifdef _CVI_
      MessagePopup ("Error", errorMessage);
   #else
      MessageBox(NULL, errorMessage, "Error", MB_OK | MB_ICONERROR);
   #endif
   }

/*****************************************************************************\
                           End example source code
\*****************************************************************************/
